- model
(function, required)
An R-function that computes the values of the derivatives
in the ODE system (the model definition) at time t.
The model must be defined as: model <- function(t, state, parms),
where t is the current time point in the integration, state is
the current value of the variables in the ODE #' system and
parms is a vector or list of parameters.
The return value of func should be a list, whose first and single
element is a vector containing the derivatives of y with respect
to time. The derivatives must be specified in the same order as
the state variables state. The vector state and parms should both
have name attributes for all their elements
- state
(numeric vector, required)
The initial (state) values for the ODE system. This vector should
have name attributes for all its elements
- parms
(numeric vector, required)
The values of the parameters in the ODE system. This vector should
have name attributes for all its elements
- resume
(boolean, optional)
If TRUE the program will try to load the curves computed during
the last session from the global variable '<model>BifCurves' and try
to restore the numerical and plot settings by importing them from
the global variable '<model>BifSettings', where the substring
'<model>' is the name of the function describing the dynamics, which
is passed as first argument to 'bifurcation()'.
The program saves the curves computed during a session and the
numerical and plot settings of this last session in these global
variables '<model>BifCurves' and '<model>BifSettings'.
- ...
(optional arguments)
Additional arguments that can be included at the command line to tweak
graphical default values used by the application.
Valid arguments are:
lwd: Line width (default 3)
cex: Base font size (default 1.2)
tcl.len: Length of axes ticks (default 0.03)
bifsym: Symbol used to mark a bifurcation point
in an equilibrium curve (default: 8)
biflblpos: Location of label of a bifurcation point. Values
of 1, 2, 3 and 4, respectively, indicate positions
below, to the left of, above and to the right of
the symbol marking the bifurcation point (default: 3)
unstablelty: Line style of curve section representing unstable
equilibrium points (default: 3 (refers to dotted lines))
saveplotas: Possible values: "pdf" or "png" (default).
Save plot to PDF or PNG file.